@@ -82,10 +82,13 @@ class ContentsType(Enum):
     GasBlend = auto()
     FatOilGrease = auto()
     PrimarySludge = auto()
+    TPS = auto()
     WasteActivatedSludge = auto()
+    TWAS = auto()
     Scum = auto()
     FoodWaste = auto()
     SludgeBlend = auto()
+    ThickenedSludgeBlend = auto()
     Electricity = auto()
     Brine = auto()
     Seawater = auto()
@@ -112,6 +115,8 @@ class TagType(Enum):
 
     Flow = auto()
     Volume = auto()
+    Level = auto()
+    Pressure = auto()
     RunTime = auto()
     RunStatus = auto()
     VSS = auto()
